#!/bin/sh

#------------------------------------------------------------------------------
# opt_seti: seti.sh
#
# created 11.05.2001 schoeppi <mail@schoeppi.net>
# updated 02.08.2001 schoeppi <mail@schoeppi.net>
# twm: removed backup code
#-----------------------------------------------------------------------------
#
# starts setiathome from console or during bootup, stops the seticlient and
# shows status of current workunit
#
# usage: seti.sh [bootup | start | stop | status]
#
#-----------------------------------------------------------------------------

#----------------
# var. from /etc/seti.conf:
#--------------

. /etc/seti.conf

delay="$SETI_BOOTDELAY"
nicelevel="$SETI_NICELEVEL"
dir="$SETI_DIR"
tty="$SETI_TTY"
pidfile=/var/run/seti.pid

#--------------------------
# local var.:
#-----------------------

usage="usage: seti.sh [bootup | start | stop | status]"

if [ $# -ne 1 ] ; then
  echo "$usage"
  exit 1
fi

cmd="$1"
 
case "$cmd" in
  "bootup") ;;
  "start") ;;
  "stop") ;;
  "status") ;;
  *) echo "$usage"
    exit 1
    ;;
esac


if [ "$cmd" = "bootup" ] ; then
  if [ -f $pidfile ] ; then
    echo "setiathome is already running with pid `cat $pidfile`"
    exit 1
  fi

  if [ -f "$dir/user_info.sah" ] ; then
    echo "will be starting setiathome in $delay seconds...."
    sleep $delay
    cmd="start"
  fi
fi

if [ "$cmd" = "start" ] ; then
  if [ -f $pidfile ] ; then
    echo "setiathome is already running with pid `cat $pidfile`"
    exit 1
  fi

  if [ -f "$dir/user_info.sah" ] ; then
    echo "starting setiathome...."

    cd "$dir"
    sleep 5
    /usr/local/bin/nohupexec $tty /usr/local/bin/setiathome -verbose -nice $nicelevel &
    ln -s "$dir/pid.sah" $pidfile
    sleep 20
    echo "done."
  else
    echo "Could not find $dir/user_info.sah!"
    echo "Start setiathome manually to get your user information!"
    exit 1
  fi
fi

if [ "$cmd" = "stop" ] ; then
  if [ -f $pidfile ] ; then
    echo "stopping setiathome with pid `cat $pidfile` ..."
    kill `cat $pidfile`
    rm $pidfile
    echo "done."
    exit 0
  fi
  echo "no seticlient found."
  exit 1
fi

if [ "$cmd" = "status" ] ; then
  if [ -f $pidfile ] ; then
    echo ""
    echo "status of running seticlient and current workunit:"
    echo ""
    echo "     pid:  `cat $pidfile`"

    # prozente
    if  grep prog $dir/state.sah 1>/dev/nul  ; then
      p=`grep prog= $dir/state.sah | sed s/prog=//g`
      p=`echo $p | sed s/0[.]//g`

      # nur 3 stellen behalten
      p=`echo $p | sed s/.....$//g`

      # das nachkomma
      nk=`echo $p | sed s/^..//g`
      p=`echo $p | sed s/.$//g`

      # prog ausgeben
      echo "     prog: $p,$nk%"
    else
      echo "     prog: no value, please try later"
    fi

    # die cpuzeit
    if  grep cpu $dir/state.sah 1>/dev/nul  ; then
      c=`grep cpu= $dir/state.sah | sed s/cpu=//g`
      c=`echo $c | sed s/[.]......//g`
      h=`expr $c / 3600`
      r=`expr $c % 3600`
      m=`expr $r / 60`
      s=`expr $m '*' 60`
      s=`expr $r - $s`

      # dezimal stellen korrektur
      if [ "$h" -le "9" ] ; then
        h=`echo 0$h`
      fi

      if [ "$m" -le "9" ] ; then
        m=`echo 0$m`
      fi

      if [ "$s" -le "9" ] ; then
        s=`echo 0$s`
      fi

      # und aus den stunden tage machen wenn noetig

      if [ "$h" -gt "24" ] ; then
        d=`expr $h / 24`
        r=`expr $d '*' 24`
        h=`expr $h - $r`
        h=`echo $d days $h`
      fi

      # cpu-zeit ausgeben
      echo '     'time: $h:$m:$s

      # approximierte zeit berechnen
      ca=`expr $c '*' 1000`

      if [ "$p$nk" -ne 0 ] ; then
        ca=`expr $ca / "$p$nk"`
        c=`expr $ca - $c`
        h=`expr $c / 3600`
        r=`expr $c % 3600`
        m=`expr $r / 60`
        s=`expr $m '*' 60`
        s=`expr $r - $s`

        # dezimal stellen korrektur
        if [ "$h" -le "9" ] ; then
          h=`echo 0$h`
        fi

        if [ "$m" -le "9" ] ; then
          m=`echo 0$m`
        fi

        if [ "$s" -le "9" ] ; then
          s=`echo 0$s`
        fi

        # und aus den stunden tage machen wenn noetig

        if [ "$h" -gt "24" ] ; then
          d=`expr $h / 24`
          r=`expr $d '*' 24`
          h=`expr $h - $r`
	  h=`echo $d days $h`
        fi

        echo "     eta:  $h:$m:$s"
        echo ""
      fi
    else
      echo '     time: no value, please try later'
      echo ""
      echo "     eta:  no value, please try later"
    fi
  else
    echo "setiathome is not running"
  fi
  exit 0
fi
